/**********************************************************************************************/
/* FBL_Set.h																				  */
/*                                                                       					  */
/* Foundation Base Library ( FBL )		                                   					  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002                                       					  */
/* All Rights Reserved.                                                 					  */
/**********************************************************************************************/

#ifndef __FBL_Set_h 
	#define __FBL_Set_h

#if VSDK_FRAMEWORK_STYLE
#	include <VSDK/FBL.h>
#else
#	include <FBL.h>
#endif // VSDK_FRAMEWORK_STYLE

#if defined(__MWERKS__)
	#pragma options align=power
#endif


/**********************************************************************************************/
enum FBL_SetOperation 
{ 
		// Intersection of all sets. Logical AND. 
		// Result set contains records which belongs each set.
		// Binary operation.
	OBL_Intersection	= 1,
			
		// Union of all sets. Logical OR. 
		// Result set contains records which belongs at least one set.
		// Binary operation.	
	OBL_Union,
	
		// Difference of two set: S = S1 - S2
		// There is no logical 
		// Result set contains records which belong to S1 but not belong to S2.
		// Binary operation.
	OBL_Minus,
	
		// Symmetric difference of the sets.
		// Logical XOR (excluded OR).
		// Result set contains such records, which if it belong to one of sets
		// then it don't belong to any other.    
		// Binary operation.
	OBL_XOR 
};


/**********************************************************************************************/ 
class FBL_SetIterator;


/**********************************************************************************************/
/*
	Interface class (i.e abstract with no data memebers).
	Can be used in multiple inheritance.
	
	General purpose class. 
	Implements set of elements, i.e it can contain only one copy of an element. 
*/ 

class FBL_Set
{ 	
    public://///////////////////////////////////////////////////////////////////////////////////

								FBL_Set( void ) 	{}
virtual			  				~FBL_Set( void ) 	{}

virtual bool					IsEmpty( void ) {
									return bool( GetCount() == 0 ); 
								}

virtual ulong					GetCount( void ) const		= 0;	
virtual FBL_SetIterator*		GetIterator( void ) const	= 0;
		
};


/**********************************************************************************************/
#if defined(__MWERKS__)
	#pragma options align=reset
#endif

#endif	// __FBL_Set_h

